# conman-py
This module offers a package to manage and profile JSON configurations in Python-based libraries and web applications. It provides an environment-specific configuration management system, making it simpler to handle multiple secure and critical configurations in different environments.
